complex

Function complex 

pub fn complex<A: Number, B: Number>(real: A, imaginary: B) -> FnNumber2<A, B>
Creates a complex number from a given real coefficient and imaginary coefficient.

documentfoundation->COMPLEX

Syntax:

    COMPLEX( Real: Number; Imaginary: Number )

Constraints: None

Semantics: Constructs a complex number from the given coefficients. The third parameter Suffix is optional, and should be either “i” or “j”. Upper case “I” or “J” are not accepted for the suffix parameter.

See also: crate::of::complex_(),