complex_

Function complex_ 

pub fn complex_<A: Number, B: Number, C: Text>(
    real: A,
    imaginary: B,
    suffix: C,
) -> FnNumber3<A, B, C>
Creates a complex number from a given real coefficient and imaginary coefficient.

documentfoundation->COMPLEX

Syntax:

    COMPLEX( Real: Number; Imaginary: Number; Suffix: Text )

Constraints: None

Semantics: Constructs a complex number from the given coefficients. The third parameter Suffix is optional, and should be either “i” or “j”. Upper case “I” or “J” are not accepted for the suffix parameter.

See also: crate::of::complex(),