pub enum RomanStyle {
Classic,
SubLXV,
SubLX,
SubAllLXV,
Simplified,
}Expand description
Parameter for ROMAN().
Variants
Classic
Only subtract powers of 10, not L or V, and only if the next number is not more than 10 times greater. A number following the larger one shall be smaller than the subtracted number. Also known as classic.
SubLXV
Powers of 10, and L and V may be subtracted, only if the next number is not more than 10 times greater. A number following the larger one shall be smaller than the subtracted number.
SubLX
Powers of 10 and L, but not V, may be subtracted, also if the next number is more than 10 times greater. A number following the larger one shall be smaller than the subtracted number.
SubAllLXV
Powers of 10, and L and V may be subtracted, also if the next number is more than 10 times greater. A number following the larger one shall be smaller than the subtracted number.
Simplified
Produce the fewest Roman digits possible. Also known as simplified.