BaseUnit

Enum BaseUnit 

pub enum BaseUnit {
Show 101 variants UKAcre, USAcre, SqAngstrom, Ar, SqFoot, Hectare, SqInch, SqMeter, Morgen, SqMile, SqNauticalMile, SqPica, SqYard, Angstrom, Ell, Foot, Inch, LightYear, Meter, Mile, NauticalMile, Parsec, Pica, SurveyMile, Yard, BTU, ThermCalorie, ITCalorie, Erg, ElectronVolt, Flb, HPh, Joule, WattHour, Dyne, Newton, Lbf, Pond, Bit, Byte, Gauss, Tesla, Gram, Grain, Cwt, UKCwt, Lbm, Stone, Ton, Ozm, Sg, AtomicMassUnit, UKTon, HP, PS, Watt, Atm, MmHg, Pascal, Psi, Torr, AdmiralityKnot, Knot, MetersPerHour, MetersPerSecond, MilesPerHour, Celsius, Fahrenheit, Kelvin, Rankine, Reaumur, Day, Hour, Minute, Second, Year, CbAngstrom, Barrel, Bushel, Cup, CbFoot, Gallon, GRT, CbInch, Liter, CbLightYear, CbMeter, CbMile, MTon, CbNauticalMile, FluidOunce, CbPica, Pint, Quart, Tablespoon, Teaspoon, ModernTeaspoon, UKGallon, UKPint, UKQuart, CbYard,
}
Parameter for CONVERT().

Variants



UKAcre



USAcre



SqAngstrom



Ar



SqFoot



Hectare



SqInch



SqMeter



Morgen



SqMile



SqNauticalMile



SqPica



SqYard



Angstrom



Ell



Foot



Inch



LightYear



Meter



Mile



NauticalMile



Parsec



Pica



SurveyMile



Yard



BTU



ThermCalorie



ITCalorie



Erg



ElectronVolt



Flb



HPh



Joule



WattHour



Dyne



Newton



Lbf



Pond



Bit



Byte



Gauss



Tesla



Gram



Grain



Cwt



UKCwt



Lbm



Stone



Ton



Ozm



Sg



AtomicMassUnit



UKTon



HP



PS



Watt



Atm



MmHg



Pascal



Psi



Torr



AdmiralityKnot



Knot



MetersPerHour



MetersPerSecond



MilesPerHour



Celsius



Fahrenheit



Kelvin



Rankine



Reaumur



Day



Hour



Minute



Second



Year



CbAngstrom



Barrel



Bushel



Cup



CbFoot



Gallon



GRT



CbInch



Liter



CbLightYear



CbMeter



CbMile



MTon



CbNauticalMile



FluidOunce



CbPica



Pint



Quart



Tablespoon



Teaspoon



ModernTeaspoon



UKGallon



UKPint



UKQuart



CbYard