code

Function code 

pub fn code<A: Text>(t: A) -> FnNumber1<A>
Return numeric value corresponding to the first character of the text value.

documentfoundation->CODE

Syntax:

    CODE( T: Text )

Constraints: code point ≤ 127. Evaluators may evaluate expressions where Length(T) > 0.

Semantics:

Returns a numeric value which represents the first letter of the given text T.

Behavior for code points ≥ 128 is implementation-defined. Evaluators may use the underlying system’s code page. Evaluators should implement CODE such that CODE(CHAR(N)) returns N for 1 ≤ N ≤ 255.

Note: Where interoperability is a concern, expressions should use the UNICODE function. 6.20.26

See also: crate::of::char(), crate::of::unichar(), crate::of::unicode(),