pub fn stdeva<A: Sequence>(sample: A) -> FnNumber1<A>Expand description
Calculate the standard deviation using a sample set of values, including values of type Text and Logical.
Syntax:
STDEVA({ Sample: Any}+ )Constraints: COUNTA(Sample) > 1.
Semantics: Unlike the STDEV function, includes values of type Text and Logical. Text values are treated as number 0. Logical TRUE is treated as 1, and FALSE is treated as 0. Empty cells are not included.
The handling of string constants as parameters is implementation-defined. Either, string constants are converted to numbers, if possible and otherwise, they are treated as 0, or string constants are always treated as 0.
Suppose the resulting sequence of values is x1, x2, …, xn. Then let
STDEVA returns
See also: crate::of::counta(), crate::of::stdev(),