pub fn ceiling_precise<A: Number>(number: A) -> FnNumber1<A>Expand description
Rounds a number to the nearest multiple of a significance value. In all cases, the number is rounded up (toward +∞).
documentfoundation->CEILING.PRECISE
Syntax:
CEILING.PRECISE( Number: Number )Info2: Returns a real number that is the rounded value and is an integer multiple of the significance value.
See also: crate::of::ceiling_precise_(),