pub fn stdev<A: Sequence>(n: A) -> FnNumber1<A>Expand description
Compute the sample standard deviation of a set of numbers.
Syntax:
STDEV({ N: NumberSequenceList}+ )Constraints: At least two numbers shall be included. Returns an Error if less than two Numbers are provided.
Semantics: Computes the sample standard deviation s, where
Note that s is not the same as the standard deviation of the set, sigma, which uses n rather than n − 1.
See also: crate::of::stdevp(), crate::of::average(),